==> parse-multi-instance-2.0.0.tgz: package/lib/react-native/Parse.js <==
/**
 * Copyright (c) 2015-present, Parse, LLC.
 * All rights reserved.
 *
 * This source code is licensed under the BSD-style license found in the
 * LICENSE file in the root directory of this source tree. An additional grant
 * of patent rights can be found in the PATENTS file in the same directory.
 */

import decode from './decode';
import encode from './encode';
import { CoreManagerInstance } from './CoreManager';
import { InstallationControllerInstance } from './InstallationController';
import * as ParseOp from './ParseOp';
import { RESTControllerFacade } from './RESTController';
import { StorageFacade } from './Storage';

export default class ParseInstance {
  /**
   * Call this method first to set up your authentication tokens for Parse.
   * You can get your keys from the Data Browser on parse.com.
   * @param {String} applicationId Your Parse Application ID.
   * @param {String} javaScriptKey (optional) Your Parse JavaScript Key (Not needed for parse-server)
   * @param {String} masterKey (optional) Your Parse Master Key. (Node.js only!)
   * @static
   */
  constructor(applicationId, javaScriptKey, masterKey, coreManager) {
    if (coreManager) this._CoreManager = coreManager;else this._CoreManager = new CoreManagerInstance();

    this._initialize(applicationId, javaScriptKey, masterKey);
  }

  get CoreManager() {
    return this._CoreManager;
  }

  /**
   * Contains all Parse API classes and functions.
   * @static
   * @global
   * @class
   * @hideconstructor
   */

  _initialize(applicationId, javaScriptKey, masterKey) {
    this._CoreManager.set('APPLICATION_ID', applicationId);
    this._CoreManager.set('JAVASCRIPT_KEY', javaScriptKey);
    this._CoreManager.set('MASTER_KEY', masterKey);
    this._CoreManager.set('USE_MASTER_KEY', false);

    const ParseObjectFacade = require('./ParseObject').ParseObjectFacade;
    this.Object = new ParseObjectFacade(this._CoreManager);

    const ParseUserFacade = require('./ParseUser').ParseUserFacade;
    this.User = new ParseUserFacade(this._CoreManager);

    const ParseQueryFacade = require('./ParseQuery').ParseQueryFacade;
    this.Query = new ParseQueryFacade(this._CoreManager);

    const StorageFacade = require('./Storage').StorageFacade;
    this.Storage = new StorageFacade(this._CoreManager);

    const PushFacade = require('./Push').PushFacade;
    this.Push = new PushFacade(this._CoreManager);

    const ParseTasksFacade = require('./ParseTasks').ParseTasksFacade;
    this.Tasks = new ParseTasksFacade(this._CoreManager);

    require('./ParseHooks').ParseHooksFacade;

    this.Hooks = new ParseTasksFacade(this._CoreManager);

    const ParseSessionFacade = require('./ParseSession').ParseSessionFacade;
    this.Session = new ParseSessionFacade(this._CoreManager);

    this.Relation = require('./ParseRelation').default;
    this.ACL = require('./ParseACL').default;

    this.Role = require('./ParseRole').makeParseRole(this._CoreManager);
    this.Installation = require('./ParseInstallation').makeParseInstallation(this._CoreManager);

    this.File = require('./ParseFile').makeParseFile(this._CoreManager);

    const ParseCloudFacade = require('./Cloud').default;
    this.Cloud = new ParseCloudFacade(this._CoreManager);

    const ParseAnalyticsFacade = require('./Analytics').ParseAnalyticsFacade;
    this.Analytics = new ParseAnalyticsFacade(this._CoreManager);

    const ParseConfigFacade = require('./ParseConfig').ParseConfigFacade;
    this.Config = new ParseConfigFacade(this._CoreManager);

    this.Error = require('./ParseError').default;
    this.GeoPoint = require('./ParseGeoPoint').default;
    this.Polygon = require('./ParsePolygon').default;

    const FacebookUtilsFacade = require('./FacebookUtils').FacebookUtilsFacade;
    this.FacebookUtils = new FacebookUtilsFacade(this._CoreManager);

    this.Op = {
      Set: ParseOp.SetOp,
      Unset: ParseOp.UnsetOp,
      Increment: ParseOp.IncrementOp,
      Add: ParseOp.AddOp,
      Remove: ParseOp.RemoveOp,
      AddUnique: ParseOp.AddUniqueOp,
      Relation: ParseOp.RelationOp
    };
    this.Promise = require('./ParsePromise').default;

    const ParseSchemaFacade = require('./ParseSchema').ParseSchemaFacade;
    this.Schema = new ParseSchemaFacade(this._CoreManager);

    const LiveQueryFacade = require('./ParseLiveQuery').LiveQueryFacade;
    this.LiveQuery = new LiveQueryFacade(this._CoreManager);
    this.LiveQueryClient = require('./LiveQueryClient').default;

    this._CoreManager.setInstallationController(new InstallationControllerInstance(this._CoreManager));

    //Setting Datonis object
    const DatonisFacade = require('./Datonis').default;
    this.Datonis = new DatonisFacade("test", 5, this._CoreManager);
    this.RESTController = new RESTControllerFacade(this._CoreManager);

    this._request = (...args) => {
      return this._CoreManager.getRESTController().request.apply(this._CoreManager.getRESTController(), args);
    };
    this._ajax = (...args) => {
      return this._CoreManager.getRESTController().ajax.apply(this._CoreManager.getRESTController(), args);
    };
    // We attempt to match the signatures of the legacy versions of these methods
    this._decode = (_, value) => {
      return decode(value, this._CoreManager);
    };
    this._encode = (value, _, disallowObjects) => {
      return encode(value, disallowObjects);
    };
    this._getInstallationId = () => {
      return this._CoreManager.getInstallationController().currentInstallationId();
    };
  }

  /**
   * Call this method to set your AsyncStorage engine
   * Starting Parse@1.11, the ParseSDK do not provide a React AsyncStorage as the ReactNative module
   * is not provided at a stable path and changes over versions.
   * @param {AsyncStorage} storage a react native async storage.
   * @static
   */
  setAsyncStorage(storage) {
    this._CoreManager.setAsyncStorage(storage);
  }

  /** These legacy setters may eventually be deprecated **/
  /** 
   * @member Parse.applicationId
   * @type string
   */

  get applicationId() {
    return this._CoreManager.get('APPLICATION_ID');
  }
  set applicationId(value) {
    this._CoreManager.set('APPLICATION_ID', value);
  }

  /** 
   * @member Parse.javaScriptKey
   * @type string
   */
  get javaScriptKey() {
    return this._CoreManager.get('JAVASCRIPT_KEY');
  }
  set javaScriptKey(value) {
    this._CoreManager.set('JAVASCRIPT_KEY', value);
  }

  /** 
   * @member Parse.masterKey
   * @type string
   */
  get masterKey() {
    return this._CoreManager.get('MASTER_KEY');
  }
  set masterKey(value) {
    this._CoreManager.set('MASTER_KEY', value);
  }

  /** 
   * @member Parse.serverURL
   * @type string
   */
  get serverURL() {
    return this._CoreManager.get('SERVER_URL');
  }
  set serverURL(value) {
    this._CoreManager.set('SERVER_URL', value);
  }

  /** 
   * @member Parse.liveQueryServerURL
   * @type string
   */
  get liveQueryServerURL() {
    return this._CoreManager.get('LIVEQUERY_SERVER_URL');
  }
  set liveQueryServerURL(value) {
    this._CoreManager.set('LIVEQUERY_SERVER_URL', value);
  }

  /**
   * @member Parse.datonisURL
   * @type string
   */
  get datonisURL() {
    return this._CoreManager.get('DATONIS_URL');
  }
  set datonisURL(value) {
    this._CoreManager.set('DATONIS_URL', value);
  }
}
/* End setters */

==> parse-multi-instance-2.0.1.tgz: package/lib/react-native/Parse.js <==
/**
 * Copyright (c) 2015-present, Parse, LLC.
 * All rights reserved.
 *
 * This source code is licensed under the BSD-style license found in the
 * LICENSE file in the root directory of this source tree. An additional grant
 * of patent rights can be found in the PATENTS file in the same directory.
 */

import decode from './decode';
import encode from './encode';
import { CoreManagerInstance } from './CoreManager';
import { InstallationControllerInstance } from './InstallationController';
import * as ParseOp from './ParseOp';
import { RESTControllerFacade } from './RESTController';
import { StorageFacade } from './Storage';

export class ParseInstance {
  /**
   * Call this method first to set up your authentication tokens for Parse.
   * You can get your keys from the Data Browser on parse.com.
   * @param {String} applicationId Your Parse Application ID.
   * @param {String} javaScriptKey (optional) Your Parse JavaScript Key (Not needed for parse-server)
   * @param {String} masterKey (optional) Your Parse Master Key. (Node.js only!)
   * @static
   */
  constructor(applicationId, javaScriptKey, masterKey, coreManager) {
    if (coreManager) this._CoreManager = coreManager;else this._CoreManager = new CoreManagerInstance();

    this._initialize(applicationId, javaScriptKey, masterKey);
  }

  get CoreManager() {
    return this._CoreManager;
  }

  /**
   * Contains all Parse API classes and functions.
   * @static
   * @global
   * @class
   * @hideconstructor
   */

  _initialize(applicationId, javaScriptKey, masterKey) {
    this._CoreManager.set('APPLICATION_ID', applicationId);
    this._CoreManager.set('JAVASCRIPT_KEY', javaScriptKey);
    this._CoreManager.set('MASTER_KEY', masterKey);
    this._CoreManager.set('USE_MASTER_KEY', false);

    const ParseObjectFacade = require('./ParseObject').ParseObjectFacade;
    this.Object = new ParseObjectFacade(this._CoreManager);

    const ParseUserFacade = require('./ParseUser').ParseUserFacade;
    this.User = new ParseUserFacade(this._CoreManager);

    const ParseQueryFacade = require('./ParseQuery').ParseQueryFacade;
    this.Query = new ParseQueryFacade(this._CoreManager);

    const StorageFacade = require('./Storage').StorageFacade;
    this.Storage = new StorageFacade(this._CoreManager);

    const PushFacade = require('./Push').PushFacade;
    this.Push = new PushFacade(this._CoreManager);

    const ParseTasksFacade = require('./ParseTasks').ParseTasksFacade;
    this.Tasks = new ParseTasksFacade(this._CoreManager);

    require('./ParseHooks').ParseHooksFacade;

    this.Hooks = new ParseTasksFacade(this._CoreManager);

    const ParseSessionFacade = require('./ParseSession').ParseSessionFacade;
    this.Session = new ParseSessionFacade(this._CoreManager);

    this.Relation = require('./ParseRelation').default;
    this.ACL = require('./ParseACL').default;

    this.Role = require('./ParseRole').makeParseRole(this._CoreManager);
    this.Installation = require('./ParseInstallation').makeParseInstallation(this._CoreManager);

    this.File = require('./ParseFile').makeParseFile(this._CoreManager);

    const ParseCloudFacade = require('./Cloud').default;
    this.Cloud = new ParseCloudFacade(this._CoreManager);

    const ParseAnalyticsFacade = require('./Analytics').ParseAnalyticsFacade;
    this.Analytics = new ParseAnalyticsFacade(this._CoreManager);

    const ParseConfigFacade = require('./ParseConfig').ParseConfigFacade;
    this.Config = new ParseConfigFacade(this._CoreManager);

    this.Error = require('./ParseError').default;
    this.GeoPoint = require('./ParseGeoPoint').default;
    this.Polygon = require('./ParsePolygon').default;

    const FacebookUtilsFacade = require('./FacebookUtils').FacebookUtilsFacade;
    this.FacebookUtils = new FacebookUtilsFacade(this._CoreManager);

    this.Op = {
      Set: ParseOp.SetOp,
      Unset: ParseOp.UnsetOp,
      Increment: ParseOp.IncrementOp,
      Add: ParseOp.AddOp,
      Remove: ParseOp.RemoveOp,
      AddUnique: ParseOp.AddUniqueOp,
      Relation: ParseOp.RelationOp
    };
    this.Promise = require('./ParsePromise').default;

    const ParseSchemaFacade = require('./ParseSchema').ParseSchemaFacade;
    this.Schema = new ParseSchemaFacade(this._CoreManager);

    const LiveQueryFacade = require('./ParseLiveQuery').LiveQueryFacade;
    this.LiveQuery = new LiveQueryFacade(this._CoreManager);
    this.LiveQueryClient = require('./LiveQueryClient').default;

    this._CoreManager.setInstallationController(new InstallationControllerInstance(this._CoreManager));

    //Setting Datonis object
    const DatonisFacade = require('./Datonis').default;
    this.Datonis = new DatonisFacade("test", 5, this._CoreManager);
    this.RESTController = new RESTControllerFacade(this._CoreManager);

    this._request = (...args) => {
      return this._CoreManager.getRESTController().request.apply(this._CoreManager.getRESTController(), args);
    };
    this._ajax = (...args) => {
      return this._CoreManager.getRESTController().ajax.apply(this._CoreManager.getRESTController(), args);
    };
    // We attempt to match the signatures of the legacy versions of these methods
    this._decode = (_, value) => {
      return decode(value, this._CoreManager);
    };
    this._encode = (value, _, disallowObjects) => {
      return encode(value, disallowObjects);
    };
    this._getInstallationId = () => {
      return this._CoreManager.getInstallationController().currentInstallationId();
    };
  }

  /**
   * Call this method to set your AsyncStorage engine
   * Starting Parse@1.11, the ParseSDK do not provide a React AsyncStorage as the ReactNative module
   * is not provided at a stable path and changes over versions.
   * @param {AsyncStorage} storage a react native async storage.
   * @static
   */
  setAsyncStorage(storage) {
    this._CoreManager.setAsyncStorage(storage);
  }

  /** These legacy setters may eventually be deprecated **/
  /** 
   * @member Parse.applicationId
   * @type string
   */

  get applicationId() {
    return this._CoreManager.get('APPLICATION_ID');
  }
  set applicationId(value) {
    this._CoreManager.set('APPLICATION_ID', value);
  }

  /** 
   * @member Parse.javaScriptKey
   * @type string
   */
  get javaScriptKey() {
    return this._CoreManager.get('JAVASCRIPT_KEY');
  }
  set javaScriptKey(value) {
    this._CoreManager.set('JAVASCRIPT_KEY', value);
  }

  /** 
   * @member Parse.masterKey
   * @type string
   */
  get masterKey() {
    return this._CoreManager.get('MASTER_KEY');
  }
  set masterKey(value) {
    this._CoreManager.set('MASTER_KEY', value);
  }

  /** 
   * @member Parse.serverURL
   * @type string
   */
  get serverURL() {
    return this._CoreManager.get('SERVER_URL');
  }
  set serverURL(value) {
    this._CoreManager.set('SERVER_URL', value);
  }

  /** 
   * @member Parse.liveQueryServerURL
   * @type string
   */
  get liveQueryServerURL() {
    return this._CoreManager.get('LIVEQUERY_SERVER_URL');
  }
  set liveQueryServerURL(value) {
    this._CoreManager.set('LIVEQUERY_SERVER_URL', value);
  }

  /**
   * @member Parse.datonisURL
   * @type string
   */
  get datonisURL() {
    return this._CoreManager.get('DATONIS_URL');
  }
  set datonisURL(value) {
    this._CoreManager.set('DATONIS_URL', value);
  }
}
/* End setters */

export default ParseInstance;
